@@ -17,21 +17,31 @@ pub async fn exec(sub_m: &ArgMatches) -> Result<()> {
             if sub_m.is_present("std") {
                 let latest_std = get_latest_std().await;
 
-                let data = &format!("https://deno.land/std@{}/{}/mod.ts", latest_std, module);
+                let std_module = &format!("https://deno.land/std@{}/{}/mod.ts", latest_std, module);
                 let mut deps = CONFIG.dependencies.as_ref().unwrap().clone();
-                deps.insert((&module).to_string(), data.to_string());
+                deps.insert((&module).to_string(), std_module.to_string());
                 //Errors otherwise
                 if DIPLO_CONFIG.ends_with(".toml") {
-                    //Cant error cause it would default to json
-                    let data = read_to_string(&*DIPLO_CONFIG).unwrap();
-                    let mut document = data.parse::<Document>().unwrap();
-                    for (name, val) in deps.iter() {
-                        document["dependencies"][name] = value(val);
+                    let data = read_to_string(&*DIPLO_CONFIG);
+                    if let Ok(data) = data {
+                        let mut document = data.parse::<Document>().unwrap();
+                        for (name, val) in deps.iter() {
+                            document["dependencies"][name] = value(val);
+                        }
+                        update_config_toml(document);
+                        println!(
+                            "Successfully added {} to the dependencies",
+                            std_module.green()
+                        );
+                    } else {
+                        println!("Could not locate {}", &*DIPLO_CONFIG);
+                        println!("please initialize diplo with diplo init");
                     }
-                    update_config_toml(document);
-                    println!("Successfully added {} to the dependencies", data.green());
                 } else if let true = update_config_json(json!({ "dependencies": deps })) {
-                    println!("Successfully added {} to the dependencies", data.green());
+                    println!(
+                        "Successfully added {} to the dependencies",
+                        std_module.green()
+                    );
                 }
             } else {
                 let res = HTTP_CLIENT
@@ -56,17 +66,22 @@ pub async fn exec(sub_m: &ArgMatches) -> Result<()> {
                     //Errors otherwise
                     if DIPLO_CONFIG.ends_with(".toml") {
                         //Cant error cause it would default to json
-                        let data = read_to_string(&*DIPLO_CONFIG).unwrap();
-                        let mut document = data.parse::<Document>().unwrap();
-                        for (name, val) in deps.iter() {
-                            document["dependencies"][name] = value(val);
+                        let data = read_to_string(&*DIPLO_CONFIG);
+                        if let Ok(data) = data {
+                            let mut document = data.parse::<Document>().unwrap();
+                            for (name, val) in deps.iter() {
+                                document["dependencies"][name] = value(val);
+                            }
+                            update_config_toml(document);
+                            println!(
+                                "Successfully added {}@{} to the dependencies",
+                                module.yellow(),
+                                json.latest.yellow()
+                            )
+                        } else {
+                            println!("Could not locate {}", &*DIPLO_CONFIG);
+                            println!("please initialize diplo with diplo init");
                         }
-                        update_config_toml(document);
-                        println!(
-                            "Successfully added {}@{} to the dependencies",
-                            module.yellow(),
-                            json.latest.yellow()
-                        )
                     } else if let true = update_config_json(json!({ "dependencies": deps })) {
                         println!(
                             "Successfully added {}@{} to the dependencies",
