@@ -1,7 +1,11 @@
 use crate::{load_config::create_deps, CONFIG, DOTDIPLO};
 use anyhow::Result;
+use colored::Colorize;
 use serde_json::json;
-use std::{fs::write, process::Command};
+use std::{
+    fs::{create_dir_all, write},
+    process::Command,
+};
 
 pub fn exec() -> Result<()> {
     if let Some(dependencies) = &CONFIG.dependencies {
@@ -17,19 +21,27 @@ pub fn exec() -> Result<()> {
             }
         }
     }
-    let mut out = Command::new("deno")
+    if let Err(e) = create_dir_all(&*DOTDIPLO) {
+        println!("Error while creating {}", &*DOTDIPLO.red());
+        println!("{}", format!("{:#?}", e).red());
+        return Ok(());
+    }
+    let out = Command::new("deno")
         .args(vec![
             "cache",
-            ".diplo/deps.ts",
+            &*format!("{}/deps.ts", &*DOTDIPLO),
             "--quiet",
-            "--lock=.diplo/deno-lock.json",
+            &*format!("--lock={}/deno-lock.json", &*DOTDIPLO),
             "--lock-write",
-            ".diplo/deno-lock.json",
+            &*format!("{}/deno-lock.json", &*DOTDIPLO),
         ])
-        .spawn()
-        .unwrap();
-    if let Err(error) = out.wait() {
-        println!("{}", error);
+        .spawn();
+    if let Err(out) = out {
+        println!("Error occured: {:#?}", out);
+        return Ok(());
+    } else if let Err(error) = out.unwrap().wait() {
+        println!("{:#?}", error);
+        return Ok(());
     }
     println!("Successfully cached the dependencies");
 
