@@ -1,12 +1,9 @@
-use anyhow::Result;
-
-use diplo::{
-    info,
+use crate::{
     load_config::{update_config_json, update_config_toml},
-    term::print_inner,
     update_deno::update_deps,
     CONFIG, DIPLO_CONFIG,
 };
+use anyhow::Result;
 use serde_json::json;
 use std::fs::read_to_string;
 use toml_edit::{value, Document};
@@ -22,7 +19,7 @@ pub async fn exec() -> Result<()> {
         }
         update_config_toml(document);
     } else if let true = update_config_json(json!({ "dependencies": &newdeps })) {
-        info!("updating done!");
+        println!("updating done!");
     }
 
     Ok(())
